@@ -7,6 +7,7 @@
  * Contract with IBM Corp.
  * Copyright (c) 2020 Red Hat, Inc.
  ****************************************************************************** */
+// Copyright Contributors to the Open Cluster Management project
 
 import _ from 'lodash';
 import { gql } from 'apollo-server-express';
@@ -16,6 +17,7 @@ import * as json from './json';
 import * as query from './query';
 import * as search from './search';
 import * as userSearch from './user-search';
+import * as message from './message';
 
 const modules = [
   application,
@@ -23,6 +25,7 @@ const modules = [
   query,
   search,
   userSearch,
+  message,
 ];
 
 const mainDefs = [gql`
